@@ -1,6 +1,6 @@
 /***************************************************************************
  *   KMidimon - ALSA sequencer based MIDI monitor                          *
- *   Copyright (C) 2005-2009 Pedro Lopez-Cabanillas                        *
+ *   Copyright (C) 2005-2013 Pedro Lopez-Cabanillas                        *
  *   plcl@users.sourceforge.net                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,6 +19,8 @@
  *   MA 02110-1301, USA                                                    *
  ***************************************************************************/
 
+#include "connectdlg.h"
+
 #include <QGroupBox>
 #include <QVBoxLayout>
 #include <QCheckBox>
@@ -27,8 +29,6 @@
 #include <klocale.h>
 #include <kcombobox.h>
 
-#include "connectdlg.h"
-
 ConnectDlg::ConnectDlg( QWidget *parent,
                         const QStringList& inputs,
                         const QStringList& subs,
@@ -70,7 +70,7 @@ QStringList ConnectDlg::getSelectedInputs() const
     QList<QCheckBox*> checks = m_group->findChildren<QCheckBox*> ();
     foreach ( QCheckBox* chk, checks ) {
         if (chk->isChecked()) {
-            lst += chk->text().remove("&");
+            lst += chk->text().remove('&');
         }
     }
     return lst;
