@@ -1,6 +1,6 @@
 /***************************************************************************
  *   KMidimon - ALSA sequencer based MIDI monitor                          *
- *   Copyright (C) 2005-2010 Pedro Lopez-Cabanillas                        *
+ *   Copyright (C) 2005-2013 Pedro Lopez-Cabanillas                        *
  *   plcl@users.sourceforge.net                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,6 +28,18 @@
 #include "sequenceradaptor.h"
 #include "slideraction.h"
 
+#include <QMenu>
+#include <QEvent>
+#include <QContextMenuEvent>
+#include <QCursor>
+#include <QTreeView>
+#include <QTextStream>
+#include <QSignalMapper>
+#include <QVariant>
+#include <QToolTip>
+#include <QFileInfo>
+#include <QDropEvent>
+
 #include <KLocale>
 #include <KAction>
 #include <KApplication>
@@ -49,18 +61,6 @@
 #include <KMessageBox>
 #include <KIO/NetAccess>
 
-#include <QMenu>
-#include <QEvent>
-#include <QContextMenuEvent>
-#include <QCursor>
-#include <QTreeView>
-#include <QTextStream>
-#include <QSignalMapper>
-#include <QVariant>
-#include <QToolTip>
-#include <QFileInfo>
-#include <QDropEvent>
-
 KMidimon::KMidimon() :
     KXmlGuiWindow(0),
     m_adaptor(0)
@@ -68,6 +68,8 @@ KMidimon::KMidimon() :
     QWidget *vbox = new QWidget(this);
     QVBoxLayout *layout = new QVBoxLayout;
     m_useFixedFont = false;
+    m_autoResizeColumns = false;
+    m_requestRealtimePrio = false;
     m_mapper = new QSignalMapper(this);
     m_model = new SequenceModel(this);
     m_proxy = new ProxyModel(this);
@@ -88,7 +90,7 @@ KMidimon::KMidimon() :
         m_adaptor->setModel(m_model);
         m_adaptor->updateModelClients();
         connect( m_model, SIGNAL(rowsInserted(QModelIndex,int,int)),
-                          SLOT(resizeColumns(QModelIndex,int,int)) );
+                          SLOT(modelRowsInserted(QModelIndex,int,int)) );
         connect( m_adaptor, SIGNAL(signalTicks(int)), SLOT(slotTicks(int)));
         connect( m_adaptor, SIGNAL(finished()), SLOT(songFinished()));
         m_tabBar = new KTabBar(this);
@@ -190,7 +192,7 @@ void KMidimon::setupActions()
     m_play = new KAction(this);
     m_play->setText(i18n("&Play"));
     m_play->setIcon(KIcon("media-playback-start"));
-    m_play->setShortcut( Qt::Key_P );
+    m_play->setShortcut( Qt::Key_MediaPlay );
     m_play->setWhatsThis(i18n("Start playback of the current session"));
     connect(m_play, SIGNAL(triggered()), SLOT(play()));
     actionCollection()->addAction("play", m_play);
@@ -219,7 +221,7 @@ void KMidimon::setupActions()
     m_record = new KAction(this);
     m_record->setText(i18n("Record"));
     m_record->setIcon(KIcon("media-record"));
-    m_record->setShortcut( Qt::Key_R );
+    m_record->setShortcut( Qt::Key_MediaRecord );
     m_record->setWhatsThis(i18n("Append new recorded events to the current session"));
     connect(m_record, SIGNAL(triggered()), SLOT(record()));
     actionCollection()->addAction("record", m_record);
@@ -227,7 +229,7 @@ void KMidimon::setupActions()
     m_stop = new KAction(this);
     m_stop->setText( i18n("Stop") );
     m_stop->setIcon(KIcon("media-playback-stop"));
-    m_stop->setShortcut( Qt::Key_S );
+    m_stop->setShortcut( Qt::Key_MediaStop );
     m_stop->setWhatsThis(i18n("Stop playback or recording"));
     connect(m_stop, SIGNAL(triggered()), SLOT(stop()));
     actionCollection()->addAction("stop", m_stop);
@@ -400,6 +402,12 @@ void KMidimon::openURL(const KUrl& url)
         KIO::NetAccess::removeTempFile(tmpFile);
         updateCaption();
         delete m_pd;
+        QString loadingMsg = m_model->getLoadingMessages();
+        if (!loadingMsg.isEmpty()) {
+            loadingMsg.insert(0,
+                i18n("Warning, this file may be non-standard or damaged.<br/>"));
+            KMessageBox::sorry(this, loadingMsg, i18n("File parsing error"));
+        }
     }
 }
 
@@ -407,7 +415,7 @@ void KMidimon::fileOpen()
 {
     KUrl u = KFileDialog::getOpenUrl(
             KUrl("kfiledialog:///MIDIMONITOR"),
-            "audio/midi audio/cakewalk", this,
+            "audio/midi audio/cakewalk audio/overture", this,
             i18n("Open MIDI file"));
     if (!u.isEmpty()) openURL(u);
 }
@@ -431,6 +439,7 @@ void KMidimon::fileSave()
 
 bool KMidimon::queryExit()
 {
+    stop();
     saveConfiguration();
     return true;
 }
@@ -442,6 +451,7 @@ void KMidimon::saveConfiguration()
     if (m_adaptor == NULL) return;
     config.writeEntry("resolution", m_defaultResolution);
     config.writeEntry("tempo", m_defaultTempo);
+    config.writeEntry("realtime_prio", m_requestRealtimePrio);
     config.writeEntry("alsa", m_proxy->showAlsaMsg());
     config.writeEntry("channel", m_proxy->showChannelMsg());
     config.writeEntry("common", m_proxy->showCommonMsg());
@@ -455,6 +465,7 @@ void KMidimon::saveConfiguration()
     config.writeEntry("instrument", m_model->getInstrumentName());
     config.writeEntry("encoding", m_model->getEncoding());
     config.writeEntry("fixed_font", getFixedFont());
+    config.writeEntry("auto_resize", m_autoResizeColumns);
     for (i = 0; i < COLUMN_COUNT; ++i) {
         config.writeEntry(QString("show_column_%1").arg(i),
                 m_popupAction[i]->isChecked());
@@ -486,11 +497,14 @@ void KMidimon::readConfiguration()
     m_model->setTranslateCtrls(config.readEntry("translate_ctrls", false));
     m_model->setInstrumentName(config.readEntry("instrument", QString()));
     m_model->setEncoding(config.readEntry("encoding", QString()));
+    m_autoResizeColumns = config.readEntry("auto_resize", false);
     m_defaultResolution = config.readEntry("resolution", RESOLUTION);
     m_defaultTempo = config.readEntry("tempo", TEMPO_BPM);
+    m_requestRealtimePrio = config.readEntry("realtime_prio", false);
     m_adaptor->setResolution(m_defaultResolution);
     m_adaptor->setTempo(m_defaultTempo);
     m_adaptor->queue_set_tempo();
+    m_adaptor->setRequestRealtime(m_requestRealtimePrio);
     setFixedFont(config.readEntry("fixed_font", false));
     for (i = 0; i < COLUMN_COUNT; ++i) {
         status = config.readEntry(QString("show_column_%1").arg(i), true);
@@ -512,6 +526,7 @@ void KMidimon::preferences()
     QPointer<ConfigDialog> dlg = new ConfigDialog(this);
     dlg->setTempo(m_defaultTempo);
     dlg->setResolution(m_defaultResolution);
+    dlg->setRequestRealtime(m_requestRealtimePrio);
     dlg->setRegAlsaMsg(m_proxy->showAlsaMsg());
     dlg->setRegChannelMsg(m_proxy->showChannelMsg());
     dlg->setRegCommonMsg(m_proxy->showCommonMsg());
@@ -526,6 +541,7 @@ void KMidimon::preferences()
     dlg->setInstrumentName(m_model->getInstrumentName());
     dlg->setEncoding(m_model->getEncoding());
     dlg->setUseFixedFont(getFixedFont());
+    dlg->setResizeColumns(m_autoResizeColumns);
     for (i = 0; i < COLUMN_COUNT; ++i) {
         dlg->setShowColumn(i, m_popupAction[i]->isChecked());
     }
@@ -545,12 +561,15 @@ void KMidimon::preferences()
             m_model->setTranslateCtrls(dlg->translateCtrls());
             m_model->setInstrumentName(dlg->getInstrumentName());
             m_model->setEncoding(dlg->getEncoding());
+            m_autoResizeColumns = dlg->resizeColumns();
             m_defaultTempo = dlg->getTempo();
             m_defaultResolution = dlg->getResolution();
             setFixedFont(dlg->useFixedFont());
             for (i = 0; i < COLUMN_COUNT; ++i) {
                 setColumnStatus(i, dlg->showColumn(i));
             }
+            m_requestRealtimePrio = dlg->requestRealtime();
+            m_adaptor->setRequestRealtime(m_requestRealtimePrio);
             if (was_running) record();
         }
     }
@@ -591,8 +610,10 @@ void KMidimon::play()
 void KMidimon::pause()
 {
     m_adaptor->pause(m_pause->isChecked());
-    //if (m_adaptor->isPaused())
-    //  updateState("paused_state", i18nc("player paused","paused"));
+    if (m_adaptor->isPaused())
+        updateState("paused_state", i18nc("player paused","paused"));
+    else
+        updateState("playing_state", i18nc("player playing","playing"));
 }
 
 void KMidimon::rewind()
@@ -612,7 +633,7 @@ void KMidimon::updateCaption()
     QFileInfo finfo(m_file);
     QString name = finfo.fileName();
     if (name.isEmpty())
-        name = i18n("(empty)");
+        name = i18n("(no file)");
     setCaption(i18n("%1 [%2]", name, m_currentState));
 }
 
@@ -707,9 +728,10 @@ void KMidimon::setFixedFont(bool newValue)
     }
 }
 
-void KMidimon::resizeColumns(const QModelIndex&, int, int)
+void KMidimon::modelRowsInserted(const QModelIndex&, int, int)
 {
-	resizeAllColumns();
+    if (m_autoResizeColumns)
+        resizeAllColumns();
     m_view->scrollToBottom();
 }
 
