@@ -1,6 +1,6 @@
 /*
-    KMidimon - ALSA sequencer based MIDI monitor                          *
-    Copyright (C) 2005-2010 Pedro Lopez-Cabanillas                        *
+    KMidimon - ALSA sequencer based MIDI monitor
+    Copyright (C) 2005-2013 Pedro Lopez-Cabanillas <plcl@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 
 #include "player.h"
 #include <alsaqueue.h>
-#include <kdebug.h>
 
 Player::Player(MidiClient *seq, int portId)
     : SequencerOutputThread(seq, portId),
@@ -121,18 +120,12 @@ void Player::run()
             }
             while (!stopRequested() && hasNext()) {
                 SequencerEvent* ev = nextEvent();
-                /*if (getEchoResolution() > 0) {
-                    while (last_tick < ev->getTick()) {
-                        last_tick += getEchoResolution();
-                        sendEchoEvent(last_tick);
-                    }
-                }*/
                 if (!stopRequested() && !SequencerEvent::isConnectionChange(ev)) {
                     if (last_tick != ev->getTick()) {
                         last_tick = ev->getTick();
                         sendEchoEvent(last_tick);
                     }
-                    if (!m_song->mutedState(ev->getTag())) {
+                    if (!stopRequested() && !m_song->mutedState(ev->getTag())) {
                         SequencerEvent* ev2 = ev->clone();
                         ev2->setSource(m_PortId);
                         sendSongEvent(ev2);
