@@ -1,6 +1,6 @@
 /***************************************************************************
  *   KMidimon - ALSA sequencer based MIDI monitor                          *
- *   Copyright (C) 2005-2009 Pedro Lopez-Cabanillas                        *
+ *   Copyright (C) 2005-2013 Pedro Lopez-Cabanillas                        *
  *   plcl@users.sourceforge.net                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,8 +19,8 @@
  *   MA 02110-1301, USA                                                    *
  ***************************************************************************/
 
-#ifndef QT_KDE_H_
-#define QT_KDE_H_
+#ifndef QT_KDE_H
+#define QT_KDE_H
 
 // ALSA library
 #include <alsa/asoundlib.h>
@@ -79,4 +79,4 @@
 #include <kxmlguifactory.h>
 #include <kxmlguiwindow.h>
 
-#endif /*QT_KDE_H_*/
+#endif /*QT_KDE_H*/
