@@ -1,6 +1,6 @@
 /***************************************************************************
  *   KMidimon - ALSA sequencer based MIDI monitor                          *
- *   Copyright (C) 2005-2010 Pedro Lopez-Cabanillas                        *
+ *   Copyright (C) 2005-2013 Pedro Lopez-Cabanillas                        *
  *   plcl@users.sourceforge.net                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,6 +28,7 @@
 #include <alsaevent.h>
 #include <qsmf.h>
 #include <qwrk.h>
+#include <qove.h>
 
 #include <QAbstractItemModel>
 #include <QMap>
@@ -89,8 +90,11 @@ public:
     void saveToFile(const QString& path);
     void loadFromFile(const QString& path);
     void appendEvent(long ticks, double seconds, int track, SequencerEvent* ev);
-    void appendSMFEvent(SequencerEvent* ev);
+
+    void appendSMFEvent(long ticks, int track, SequencerEvent* ev);
     void appendWRKEvent(long ticks, int track, SequencerEvent* ev);
+    void appendOVEEvent(long ticks, int track, SequencerEvent* ev);
+    double oveRealTime(long ticks) const;
 
     bool showClientNames() const { return m_showClientNames; }
     bool translateSysex() const { return m_translateSysex; }
@@ -132,6 +136,9 @@ public:
     QString getFileFormat() const { return m_fileFormat; }
     int getTrackForIndex(int idx);
 
+    QString getLoadingMessages() const { return m_loadingMessages; }
+    void ctlChangeEvent(int chan, int ctl, int value);
+
 public slots:
     /* SMF slots */
     void headerEvent(int format, int ntrks, int division);
@@ -141,7 +148,7 @@ public slots:
     void noteOnEvent(int chan, int pitch, int vol);
     void noteOffEvent(int chan, int pitch, int vol);
     void keyPressEvent(int chan, int pitch, int press);
-    void ctlChangeEvent(int chan, int ctl, int value);
+    void smfCtlChangeEvent(int chan, int ctl, int value);
     void pitchBendEvent(int chan, int value);
     void programEvent(int chan, int patch);
     void chanPressEvent(int chan, int press);
@@ -174,7 +181,7 @@ public slots:
     void globalVars();
     void noteEvent(int track, long time, int chan, int pitch, int vol, int dur);
     void keyPressEvent(int track, long time, int chan, int pitch, int press);
-    void ctlChangeEvent(int track, long time, int chan, int ctl, int value);
+    void wrkCtlChangeEvent(int track, long time, int chan, int ctl, int value);
     void pitchBendEvent(int track, long time, int chan, int value);
     void programEvent(int track, long time, int chan, int patch);
     void chanPressEvent(int track, long time, int chan, int press);
@@ -198,6 +205,19 @@ public slots:
     void chord(int track, long time, const QString& name, const QByteArray& data);
     void expression(int track, long time, int code, const QString& text);
 
+    /* OVE slots */
+    void oveErrorHandler(const QString& errorStr);
+    void oveFileHeader(int quarter, int trackCount);
+    void oveNoteOnEvent(int track, long tick, int channel, int pitch, int vol);
+    void oveNoteOffEvent(int track, long tick, int channel, int pitch, int vol);
+    void oveTrackPatch(int track, int channel, int patch);
+    void oveTrackVol(int track, int channel, int vol);
+    void oveTrackBank(int track, int channel, int bank);
+    void oveTextEvent(int track, long tick, const QString& data);
+    void oveTimeSigEvent(int bar, long tick, int num, int den);
+    void oveKeySigEvent(int bar, long tick, int alt);
+    void oveTempoEvent(long time, int tempo);
+
 signals:
     void loadProgress(int);
 
@@ -229,9 +249,10 @@ private:
     QString sysex_chan(const SequencerEvent *ev) const;
     QString sysex_data1(const SequencerEvent *ev) const;
     QString sysex_data2(const SequencerEvent *ev) const;
-    QString sysex_mtc_setup(const int id) const;
-    QString sysex_mtc(int id, int length, unsigned char *ptr) const;
-    QString sysex_mmc(int id, int length, unsigned char *ptr) const;
+    QString sysex_data3(const SequencerEvent *ev) const;
+    int sysex_data_first(const SequencerEvent *ev) const;
+    QString sysex_mtc(const int id) const;
+    QString sysex_mmc(const int id) const;
     QString tempo_bpm(const SequencerEvent *ev) const;
     QString tempo_npt(const SequencerEvent *ev) const;
     QString text_type(const SequencerEvent *ev) const;
@@ -250,6 +271,8 @@ private:
     bool m_translateNotes;
     bool m_translateCtrls;
     bool m_useFlats;
+    bool m_reportsFilePos;
+
     int m_currentTrack;
     int m_currentRow;
     int m_portId;
@@ -274,6 +297,7 @@ private:
     Song m_tempSong;
     QSmf* m_smf;
     QWrk* m_wrk;
+    QOve* m_ove;
     Instrument* m_ins;
     Instrument* m_ins2;
     EventFilter* m_filter;
@@ -300,6 +324,18 @@ private:
         long time;
     };
     QList<TimeSigRec> m_bars;
+
+    struct TempoRec {
+        long time;
+        double tempo;
+        double seconds;
+    };
+    QList<TempoRec> m_tempos;
+
+    typedef void (SequenceModel::*AppendFunc)(long,int,SequencerEvent*);
+    AppendFunc m_appendFunc;
+
+    QString m_loadingMessages;
 };
 
 #endif /* SEQUENCEMODEL_H */
