@@ -1,6 +1,6 @@
 /***************************************************************************
  *   KMidimon - ALSA sequencer based MIDI monitor                          *
- *   Copyright (C) 2005-2010 Pedro Lopez-Cabanillas                        *
+ *   Copyright (C) 2005-2013 Pedro Lopez-Cabanillas                        *
  *   plcl@users.sourceforge.net                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -32,7 +32,6 @@
 #include <QStringList>
 #include <kapplication.h>
 #include <klocale.h>
-#include <kdebug.h>
 
 using namespace std;
 
@@ -69,6 +68,7 @@ SequencerAdaptor::SequencerAdaptor(QObject *parent):
     m_player = new Player(m_client, m_port->getPortId());
     connect(m_player, SIGNAL(stopped()), SLOT(shutupSound()));
     connect(m_player, SIGNAL(finished()), SLOT(songFinished()));
+    m_client->setRealTimeInput(false);
     m_client->startSequencerInput();
     m_state = StoppedState;
 }
@@ -348,3 +348,18 @@ void SequencerAdaptor::removeTrackEvents(int track)
     spec.setTag(track);
     m_client->removeEvents(&spec);
 }
+
+void SequencerAdaptor::setRequestRealtime(bool newValue)
+{
+    bool old = requestedRealtime();
+    if (old != newValue && m_state == StoppedState) {
+        m_client->stopSequencerInput();
+        m_client->setRealTimeInput(newValue);
+        m_client->startSequencerInput();
+    }
+}
+
+bool SequencerAdaptor::requestedRealtime()
+{
+    return m_client->realTimeInputEnabled();
+}
